==> sso-contract-1.1.7-sources.jar: cn/com/duiba/sso/api/domain/dto/AdminDto.java <==
package cn.com.duiba.sso.api.domain.dto;

import cn.com.duiba.sso.api.domain.enums.SystemEnum;
import com.google.common.collect.Sets;

import java.io.Serializable;
import java.util.Date;
import java.util.Set;

/**
 * Created by liuyao on 2017/5/11.
 */
public class AdminDto implements Serializable {

    private static final long serialVersionUID = 4264258296954554274L;

    private Long id;

    private String name;

    private String account;

    private Boolean enable;

    private String tokenSecret;

    private Boolean superAdmin;

    private Boolean canRecharge;// 是否有充值的权限

    private Integer staffId;//内部活动的用户Id

    private String email;//邮箱

    private String mobile; //手机号

    private Date gmtCreate;

    private Date gmtModified;

    private Set<Long> systemIdSet = Sets.newHashSet();

    private Set<SystemEnum> companyEnumSet = Sets.newHashSet();

    private SystemEnum system;

    private boolean isRoleSuperAuth;//该角色是否拥有所有数据查看权限。

    private boolean sensitiveDataAuth; //该角色是否拥有敏感数据权限(邮箱和手机号)

    public boolean isSensitiveDataAuth() {
        return sensitiveDataAuth;
    }

    public void setSensitiveDataAuth(boolean sensitiveDataAuth) {
        this.sensitiveDataAuth = sensitiveDataAuth;
    }

    public boolean getIsRoleSuperAuth(){return isRoleSuperAuth;}

    public void setIsRoleSuperAuth(boolean isRoleSuperAuth){this.isRoleSuperAuth = isRoleSuperAuth;}

    public Long getId() {
        return id;
    }

    public void setId(Long id) {
        this.id = id;
    }

    public String getName() {
        return name;
    }

    public void setName(String name) {
        this.name = name;
    }

    public String getAccount() {
        return account;
    }

    public void setAccount(String account) {
        this.account = account;
    }

    public Boolean getEnable() {
        return enable;
    }

    public void setEnable(Boolean enable) {
        this.enable = enable;
    }

    public String getTokenSecret() {
        return tokenSecret;
    }

    public void setTokenSecret(String tokenSecret) {
        this.tokenSecret = tokenSecret;
    }

    public Boolean getSuperAdmin() {
        return superAdmin;
    }

    public void setSuperAdmin(Boolean superAdmin) {
        this.superAdmin = superAdmin;
    }

    public Boolean getCanRecharge() {
        return canRecharge;
    }

    public void setCanRecharge(Boolean canRecharge) {
        this.canRecharge = canRecharge;
    }

    public Integer getStaffId() {
        return staffId;
    }

    public void setStaffId(Integer staffId) {
        this.staffId = staffId;
    }

    public Date getGmtCreate() {
        return gmtCreate;
    }

    public void setGmtCreate(Date gmtCreate) {
        this.gmtCreate = gmtCreate;
    }

    public Date getGmtModified() {
        return gmtModified;
    }

    public void setGmtModified(Date gmtModified) {
        this.gmtModified = gmtModified;
    }

    public String getEmail() {
        return email;
    }

    public void setEmail(String email) {
        this.email = email;
    }

    public Set<Long> getSystemIdSet() {
        return systemIdSet;
    }

    public void setSystemIdSet(Set<Long> systemIdSet) {
        this.systemIdSet = systemIdSet;
    }

    public Set<SystemEnum> getCompanyEnumSet() {
        return companyEnumSet;
    }

    public void setCompanyEnumSet(Set<SystemEnum> companyEnumSet) {
        this.companyEnumSet = companyEnumSet;
    }

    public void setSystem(SystemEnum system){
        this.system = system;
    }

    public SystemEnum getSystem(){
        return this.system;
    }

    public String getMobile() {
        return mobile;
    }

    public void setMobile(String mobile) {
        this.mobile = mobile;
    }
}

==> sso-contract-1.5.5-sources.jar: cn/com/duiba/sso/api/domain/dto/AdminDto.java <==
package cn.com.duiba.sso.api.domain.dto;

import com.google.common.collect.Sets;

import java.io.Serializable;
import java.util.Date;
import java.util.Set;

/**
 * Created by liuyao on 2017/5/11.
 */
public class AdminDto implements Serializable {

    private static final long serialVersionUID = 4264258296954554274L;

    private Long id;

    private String name;

    private String account;

    private Boolean enable;

    private String tokenSecret;

    private Boolean superAdmin;

    private Boolean canRecharge;// 是否有充值的权限

    private Integer staffId;//内部活动的用户Id

    private String email;//邮箱

    private String mobile; //手机号

    private Date gmtCreate;

    private Date gmtModified;

    private Set<Long> systemIdSet = Sets.newHashSet();

    private boolean isRoleSuperAuth;//该角色是否拥有所有数据查看权限。

    private boolean sensitiveDataAuth; //该角色是否拥有敏感数据权限(邮箱和手机号)

    private String dingUserId; //该用户在钉钉中的Id

    public String getDingUserId() {
        return dingUserId;
    }

    public void setDingUserId(String dingUserId) {
        this.dingUserId = dingUserId;
    }

    public boolean isSensitiveDataAuth() {
        return sensitiveDataAuth;
    }

    public void setSensitiveDataAuth(boolean sensitiveDataAuth) {
        this.sensitiveDataAuth = sensitiveDataAuth;
    }

    public boolean getIsRoleSuperAuth(){return isRoleSuperAuth;}

    public void setIsRoleSuperAuth(boolean isRoleSuperAuth){this.isRoleSuperAuth = isRoleSuperAuth;}

    public Long getId() {
        return id;
    }

    public void setId(Long id) {
        this.id = id;
    }

    public String getName() {
        return name;
    }

    public void setName(String name) {
        this.name = name;
    }

    public String getAccount() {
        return account;
    }

    public void setAccount(String account) {
        this.account = account;
    }

    public Boolean getEnable() {
        return enable;
    }

    public void setEnable(Boolean enable) {
        this.enable = enable;
    }

    public String getTokenSecret() {
        return tokenSecret;
    }

    public void setTokenSecret(String tokenSecret) {
        this.tokenSecret = tokenSecret;
    }

    public Boolean getSuperAdmin() {
        return superAdmin;
    }

    public void setSuperAdmin(Boolean superAdmin) {
        this.superAdmin = superAdmin;
    }

    public Boolean getCanRecharge() {
        return canRecharge;
    }

    public void setCanRecharge(Boolean canRecharge) {
        this.canRecharge = canRecharge;
    }

    public Integer getStaffId() {
        return staffId;
    }

    public void setStaffId(Integer staffId) {
        this.staffId = staffId;
    }

    public Date getGmtCreate() {
        return gmtCreate;
    }

    public void setGmtCreate(Date gmtCreate) {
        this.gmtCreate = gmtCreate;
    }

    public Date getGmtModified() {
        return gmtModified;
    }

    public void setGmtModified(Date gmtModified) {
        this.gmtModified = gmtModified;
    }

    public String getEmail() {
        return email;
    }

    public void setEmail(String email) {
        this.email = email;
    }

    public Set<Long> getSystemIdSet() {
        return systemIdSet;
    }

    public void setSystemIdSet(Set<Long> systemIdSet) {
        this.systemIdSet = systemIdSet;
    }

    public String getMobile() {
        return mobile;
    }

    public void setMobile(String mobile) {
        this.mobile = mobile;
    }
}
